@@ -1,6 +1,4 @@
-"""
-TODO: Ignore fields with init=False.
-"""
+"""Implementation module."""
 
 from __future__ import annotations
 
@@ -16,14 +14,14 @@ from importlib import import_module
 from inspect import cleandoc, get_annotations, getmodule, getsource, isabstract
 from pathlib import Path
 from textwrap import dedent
-from types import ModuleType, NoneType, UnionType
+from types import MappingProxyType, ModuleType, NoneType, UnionType
 from typing import Any, BinaryIO, ClassVar, Generic, TypeVar, Union, cast, get_args, get_origin
 from weakref import WeakKeyDictionary
 
 if sys.version_info < (3, 11):
-    import tomli as tomllib
+    import tomli as tomllib  # pragma: no cover
 else:
-    import tomllib
+    import tomllib  # pragma: no cover
 
 
 def _collect_type(field_type: type, context: str) -> type:
@@ -161,8 +159,24 @@ def _get_fields(cls: type) -> Iterator[tuple[str, type]]:
 
     This includes fields inherited from superclasses.
     """
+
+    fields_by_name = {field.name: field for field in fields(cls)}
+
+    # Note: getmodule() can return None, but the end result is still fine.
+    cls_globals = getattr(getmodule(cls), "__dict__", {})
+    cls_locals = vars(cls)
+
     for field_container in reversed(cls.__mro__):
-        yield from get_annotations(field_container, eval_str=True).items()
+        for name, annotation in get_annotations(field_container).items():
+            field = fields_by_name[name]
+            if not field.init:
+                continue
+            if isinstance(annotation, str):
+                try:
+                    annotation = eval(annotation, cls_globals, cls_locals)
+                except NameError as ex:
+                    raise TypeError(f"Failed to parse annotation of field '{cls.__name__}.{name}': {ex}") from None
+            yield name, annotation
 
 
 _TIMEDELTA_SUFFIXES = {"days", "seconds", "microseconds", "milliseconds", "minutes", "hours", "weeks"}
@@ -245,7 +259,7 @@ class Binder(Generic[T]):
             key_type, elem_type = get_args(field_type)
             mapping = {key: cls._bind_to_field(elem, elem_type, f'{context}["{key}"]') for key, elem in value.items()}
             return (
-                (mapping if isinstance(origin, MutableMapping) else mapping.items())
+                (mapping if isinstance(origin, MutableMapping) else MappingProxyType(mapping))
                 if isabstract(origin)
                 else field_type(mapping)
             )
@@ -562,6 +576,9 @@ def format_template(class_or_instance: Any) -> Iterator[str]:
 
     first = True
     for field in fields(config_class):
+        if not field.init:
+            continue
+
         if first:
             first = False
         else:
